@@ -3,7 +3,9 @@ implementations of it."""
 
 from . import action_spaces
 from ._base import Base
+from ._factory import Factory
 from ._simulator_wrapper import SimulatorWrapper
+from ._gym_wrapper import GymWrapper
 
 
-__all__ = ["Base", "SimulatorWrapper", "action_spaces"]
+__all__ = ["Base", "SimulatorWrapper", "action_spaces", "Factory", "GymWrapper"]
