@@ -1,8 +1,10 @@
-from typing import Dict, Tuple
+from typing import Dict, Optional, Tuple
 from abc import ABC, abstractmethod
 
 import numpy as np
-from . import action_spaces
+
+import ai.environments as environments
+import ai.utils.logging as logging
 
 
 class Base(ABC):
@@ -14,7 +16,7 @@ class Base(ABC):
 
     @property
     @abstractmethod
-    def action_space(self) -> action_spaces.Base:
+    def action_space(self) -> environments.action_spaces.Base:
         """The action space instance used by the environment instance."""
         raise NotImplementedError
 
@@ -39,3 +41,22 @@ class Base(ABC):
             flag, and debugging dictionary.
         """
         raise NotImplementedError
+
+    @abstractmethod
+    def close(self):
+        """Disposes resources used by the environment."""
+        raise NotImplementedError
+
+    @abstractmethod
+    def render(self):
+        """Renders the environment in its current state."""
+        raise NotImplementedError
+
+    @classmethod
+    def get_factory(cls, *args, **kwargs) -> "environments.Factory":
+        """Creates and returns a factory object that spawns simulators when called.
+
+        Args and kwargs are passed along to the class constructor. However, if other
+        behavior is required, feel free to override this method and return a factory
+        class of your choice."""
+        return environments.Factory(cls, *args, **kwargs)
