@@ -2,13 +2,21 @@ from typing import Tuple, Dict
 
 import numpy as np
 
-import ai.simulators as simulators
+from ai import simulators
 import ai.environments as environments
 
 
 class SimulatorWrapper(environments.Base):
     """Environment that wraps a simulator, exposing it as an environment."""
 
+    class Factory(environments.Factory):
+        def __init__(self, factory: simulators.Factory):
+            self._factory = factory
+
+        def __call__(self) -> "SimulatorWrapper":
+            return SimulatorWrapper(self._factory())
+
+
     def __init__(self, simulator: simulators.Base):
         """
         Args:
@@ -36,3 +44,14 @@ class SimulatorWrapper(environments.Base):
         self._state, self._action_mask = self._simulator.reset()
         self._ready = True
         return self._state, self._action_mask
+
+    def close(self):
+        self._simulator.close()
+
+    def render(self):
+        self._simulator.render(self._state)
+
+    @classmethod
+    def get_factory(cls, factory: simulators.Factory) -> "SimulatorWrapper.Factory":
+        """Wraps a simulator factory into an environment factory."""
+        return SimulatorWrapper.Factory(factory)
