@@ -2,10 +2,10 @@ from abc import abstractmethod
 
 import numpy as np
 
-from ._base import Base
+import ai.environments.action_spaces as action_spaces
 
 
-class Discrete(Base):
+class Discrete(action_spaces.Base):
     """Discrete action space.
 
     Discrete action spaces identify actions using the an integer and have a fixed size.
