@@ -1,6 +1,7 @@
 """Contains general PyTorch utility methods."""
 
-from . import random
+
+from . import nn, random
 
 
-__all__ = ["random"]
+__all__ = ["nn", "random"]
